@@ -826,7 +826,9 @@ void gtranslator_learn_export_to_po_file(const gchar *po_file)
 	 *   the learn buffer/language settings of the user.
 	 */
 	fprintf(file, 
-"\n\"Project-Id-Version: gtranslator-learn-buffer %i\\n\"\n"
+"\nmsgid \"\"\n"
+"msgstr \"\"\n"
+"\"Project-Id-Version: gtranslator-learn-buffer %i\\n\"\n"
 "\"POT-Creation-Date: %s\\n\"\n"
 "\"PO-Revision-Date: %s\\n\"\n"
 "\"Last-Translator: %s <%s>\\n\"\n"
@@ -933,7 +935,7 @@ gchar *gtranslator_learn_get_learned_string(const gchar *search_string)
 	     	 * Get a new query string without any punctuation characters.
 	    	 */
 		query_string=gtranslator_utils_strip_all_punctuation_chars(search_string);
-	    
+
 		/*
 		 * Try this new query.
 		 */
@@ -942,9 +944,12 @@ gchar *gtranslator_learn_get_learned_string(const gchar *search_string)
 				(gconstpointer) query_string);
 
 		/*
-		 * Don't trust too short query results .-)
+		 * Don't trust too short query results and also get a small
+		 *  similarity calculation and see if we've moved away too much
+		 *   from the original search_string.
 		 */
-		if(!found_string || strlen(found_string) <= 2)
+		if(!found_string || strlen(found_string) <= 2 ||
+			(gtranslator_utils_calculate_similarity(found_string, search_string) <= GtrPreferences.min_match_percentage))
 		{
 			return NULL;
 		}
