@@ -253,10 +253,17 @@ void gtranslator_message_show(GtrMsg *msg)
 
 void gtranslator_message_update(void)
 {
-	guint len;
-	GtrMsg *msg = GTR_MSG(po->current->data);
+	guint 
+		len,
+		pos;
+		
+	GtrMsg 
+		*msg = GTR_MSG(po->current->data);
+		
 	if (!message_changed)
 		return;
+	pos = gtk_editable_get_position( GTK_EDITABLE(trans_box) );
+	gtk_text_freeze( GTK_TEXT(trans_box) );
 	len = gtk_text_get_length(GTK_TEXT(trans_box));
 	if (len) {
 		/* Make both strings end with or without endline */
@@ -311,14 +318,16 @@ void gtranslator_message_update(void)
 	}
 	
 	/*
-	 * Check the formats of the now updated GtrMsg -- simply beep in case
-	 *  of an error for now...
+	 * Check the formats of the now updated GtrMsg -- a nerves-killing new
+	 *  feature I know...
 	 */
 	if(GtrPreferences.check_formats)
 	{
 		if(!gtranslator_formats_check(msg))
 		{
-			printf("\007");
+			gtranslator_utils_error_dialog(
+			_("The translation for message `%s'\n\
+contains syntactical errors!"), msg->msgid);
 		}
 	}
 
@@ -346,6 +355,8 @@ void gtranslator_message_update(void)
 	{
 		gtranslator_actions_enable(ACT_REMOVE_ALL_TRANSLATIONS);
 	}
+	gtk_text_thaw( GTK_TEXT(trans_box) );
+	gtk_editable_set_position( GTK_EDITABLE(trans_box), pos );
 }
 
 void gtranslator_message_change_status(GtkWidget  * item, gpointer which)
